#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class proxy_service(client.BaseClient):
    """A client for interacting with the OPNSense's proxyservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/core/blob/master/src/opnsense/mvc/app/models/OPNsense/Proxy/Proxy.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def downloadacls(self, args={}, params={}):
        """"""
        url = "proxy/service/downloadacls/"
        data = {}

        data = self._post( url, args)
        return data

    def fetchacls(self, args={}, params={}):
        """"""
        url = "proxy/service/fetchacls/"
        data = {}

        data = self._post( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "proxy/service/reconfigure/"
        data = {}

        data = self._get( url, args)
        return data

    def refreshTemplate(self, args={}, params={}):
        """"""
        url = "proxy/service/refreshTemplate/"
        data = {}

        data = self._post( url, args)
        return data

    def reset(self, args={}, params={}):
        """"""
        url = "proxy/service/reset/"
        data = {}

        data = self._post( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "proxy/service/restart/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "proxy/service/start/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "proxy/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "proxy/service/stop/"
        data = {}

        data = self._get( url, args)
        return data

class proxy_settings(client.BaseClient):
    """A client for interacting with the OPNSense's proxysettings API.
    for more information on used parameters, see : ['https://github.com/opnsense/core/blob/master/src/opnsense/mvc/app/models/OPNsense/Proxy/Proxy.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addPACMatch(self, args={}, params={}):
        """"""
        url = "proxy/settings/addPACMatch/"
        data = {}

        data = self._post( url, args)
        return data

    def addPACProxy(self, args={}, params={}):
        """"""
        url = "proxy/settings/addPACProxy/"
        data = {}

        data = self._post( url, args)
        return data

    def addPACRule(self, args={}, params={}):
        """"""
        url = "proxy/settings/addPACRule/"
        data = {}

        data = self._post( url, args)
        return data

    def addRemoteBlacklist(self, args={}, params={}):
        """"""
        url = "proxy/settings/addRemoteBlacklist/"
        data = {}

        data = self._post( url, args)
        return data

    def delPACMatch(self, args={}, params={}):
        """"""
        url = "proxy/settings/delPACMatch/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delPACProxy(self, args={}, params={}):
        """"""
        url = "proxy/settings/delPACProxy/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delPACRule(self, args={}, params={}):
        """"""
        url = "proxy/settings/delPACRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delRemoteBlacklist(self, args={}, params={}):
        """"""
        url = "proxy/settings/delRemoteBlacklist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def fetchRBCron(self, args={}, params={}):
        """"""
        url = "proxy/settings/fetchRBCron/"
        data = {}

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "proxy/settings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getPACMatch(self, args={}, params={}):
        """"""
        url = "proxy/settings/getPACMatch/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getPACProxy(self, args={}, params={}):
        """"""
        url = "proxy/settings/getPACProxy/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getPACRule(self, args={}, params={}):
        """"""
        url = "proxy/settings/getPACRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getRemoteBlacklist(self, args={}, params={}):
        """"""
        url = "proxy/settings/getRemoteBlacklist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchPACMatch(self, args={}, params={}):
        """"""
        url = "proxy/settings/searchPACMatch/"
        data = {}

        data = self._get( url, args)
        return data

    def searchPACProxy(self, args={}, params={}):
        """"""
        url = "proxy/settings/searchPACProxy/"
        data = {}

        data = self._get( url, args)
        return data

    def searchPACRule(self, args={}, params={}):
        """"""
        url = "proxy/settings/searchPACRule/"
        data = {}

        data = self._get( url, args)
        return data

    def searchRemoteBlacklists(self, args={}, params={}):
        """"""
        url = "proxy/settings/searchRemoteBlacklists/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "proxy/settings/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setPACMatch(self, args={}, params={}):
        """"""
        url = "proxy/settings/setPACMatch/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setPACProxy(self, args={}, params={}):
        """"""
        url = "proxy/settings/setPACProxy/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setPACRule(self, args={}, params={}):
        """"""
        url = "proxy/settings/setPACRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setRemoteBlacklist(self, args={}, params={}):
        """"""
        url = "proxy/settings/setRemoteBlacklist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def togglePACRule(self, args={}, params={}):
        """"""
        url = "proxy/settings/togglePACRule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleRemoteBlacklist(self, args={}, params={}):
        """"""
        url = "proxy/settings/toggleRemoteBlacklist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class proxy_template(client.BaseClient):
    """A client for interacting with the OPNSense's proxytemplate API.
    for more information on used parameters, see : ['https://github.com/opnsense/core/blob/master/src/opnsense/mvc/app/models/OPNsense/Proxy/Proxy.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "proxy/template/get/"
        data = {}

        data = self._get( url, args)
        return data

    def reset(self, args={}, params={}):
        """"""
        url = "proxy/template/reset/"
        data = {}

        data = self._post( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "proxy/template/set/"
        data = {}

        data = self._get( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class captiveportal_access(client.BaseClient):
    """A client for interacting with the OPNSense's captiveportalaccess API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def logoff(self, args={}, params={}):
        """"""
        url = "captiveportal/access/logoff/"
        data = {}

        if "zoneid" not in args.keys():
            return self.log_error("mandatory argument zoneid is missing")
        else:
            url += args.pop("zoneid")+"/"

        data = self._get( url, args)
        return data

    def logon(self, args={}, params={}):
        """"""
        url = "captiveportal/access/logon/"
        data = {}

        if "zoneid" not in args.keys():
            return self.log_error("mandatory argument zoneid is missing")
        else:
            url += args.pop("zoneid")+"/"

        data = self._post( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "captiveportal/access/status/"
        data = {}

        if "zoneid" not in args.keys():
            return self.log_error("mandatory argument zoneid is missing")
        else:
            url += args.pop("zoneid")+"/"

        data = self._post( url, args)
        return data

class captiveportal_service(client.BaseClient):
    """A client for interacting with the OPNSense's captiveportalservice API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def delTemplate(self, args={}, params={}):
        """"""
        url = "captiveportal/service/delTemplate/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def getTemplate(self, args={}, params={}):
        """"""
        url = "captiveportal/service/getTemplate/"
        data = {}

        if "fileid" not in args.keys():
            return self.log_error("mandatory argument fileid is missing")
        else:
            url += args.pop("fileid")+"/"

        data = self._get( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "captiveportal/service/reconfigure/"
        data = {}

        data = self._post( url, args)
        return data

    def saveTemplate(self, args={}, params={}):
        """"""
        url = "captiveportal/service/saveTemplate/"
        data = {}

        data = self._post( url, args)
        return data

    def searchTemplates(self, args={}, params={}):
        """"""
        url = "captiveportal/service/searchTemplates/"
        data = {}

        data = self._get( url, args)
        return data

class captiveportal_session(client.BaseClient):
    """A client for interacting with the OPNSense's captiveportalsession API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def connect(self, args={}, params={}):
        """"""
        url = "captiveportal/session/connect/"
        data = {}

        if "zoneid" not in args.keys():
            return self.log_error("mandatory argument zoneid is missing")
        else:
            url += args.pop("zoneid")+"/"

        data = self._post( url, args)
        return data

    def disconnect(self, args={}, params={}):
        """"""
        url = "captiveportal/session/disconnect/"
        data = {}

        if "zoneid" not in args.keys():
            return self.log_error("mandatory argument zoneid is missing")
        else:
            url += args.pop("zoneid")+"/"

        data = self._post( url, args)
        return data

    def list(self, args={}, params={}):
        """"""
        url = "captiveportal/session/list/"
        data = {}

        if "zoneid" not in args.keys():
            return self.log_error("mandatory argument zoneid is missing")
        else:
            url += args.pop("zoneid")+"/"

        data = self._get( url, args)
        return data

    def zones(self, args={}, params={}):
        """"""
        url = "captiveportal/session/zones/"
        data = {}

        data = self._get( url, args)
        return data

class captiveportal_settings(client.BaseClient):
    """A client for interacting with the OPNSense's captiveportalsettings API.
    for more information on used parameters, see : ['https://github.com/opnsense/core/blob/master/src/opnsense/mvc/app/models/OPNsense/CaptivePortal/CaptivePortal.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addZone(self, args={}, params={}):
        """"""
        url = "captiveportal/settings/addZone/"
        data = {}

        data = self._post( url, args)
        return data

    def delZone(self, args={}, params={}):
        """"""
        url = "captiveportal/settings/delZone/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "captiveportal/settings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getZone(self, args={}, params={}):
        """"""
        url = "captiveportal/settings/getZone/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchZones(self, args={}, params={}):
        """"""
        url = "captiveportal/settings/searchZones/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "captiveportal/settings/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setZone(self, args={}, params={}):
        """"""
        url = "captiveportal/settings/setZone/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleZone(self, args={}, params={}):
        """"""
        url = "captiveportal/settings/toggleZone/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class captiveportal_voucher(client.BaseClient):
    """A client for interacting with the OPNSense's captiveportalvoucher API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def dropExpiredVouchers(self, args={}, params={}):
        """"""
        url = "captiveportal/voucher/dropExpiredVouchers/"
        data = {}

        if "group" not in args.keys():
            return self.log_error("mandatory argument group is missing")
        else:
            url += args.pop("group")+"/"

        if "provider" not in args.keys():
            return self.log_error("mandatory argument provider is missing")
        else:
            url += args.pop("provider")+"/"

        data = self._post( url, args)
        return data

    def dropVoucherGroup(self, args={}, params={}):
        """"""
        url = "captiveportal/voucher/dropVoucherGroup/"
        data = {}

        if "group" not in args.keys():
            return self.log_error("mandatory argument group is missing")
        else:
            url += args.pop("group")+"/"

        if "provider" not in args.keys():
            return self.log_error("mandatory argument provider is missing")
        else:
            url += args.pop("provider")+"/"

        data = self._post( url, args)
        return data

    def expireVoucher(self, args={}, params={}):
        """"""
        url = "captiveportal/voucher/expireVoucher/"
        data = {}

        if "provider" not in args.keys():
            return self.log_error("mandatory argument provider is missing")
        else:
            url += args.pop("provider")+"/"

        data = self._post( url, args)
        return data

    def generateVouchers(self, args={}, params={}):
        """"""
        url = "captiveportal/voucher/generateVouchers/"
        data = {}

        if "provider" not in args.keys():
            return self.log_error("mandatory argument provider is missing")
        else:
            url += args.pop("provider")+"/"

        data = self._post( url, args)
        return data

    def listProviders(self, args={}, params={}):
        """"""
        url = "captiveportal/voucher/listProviders/"
        data = {}

        data = self._get( url, args)
        return data

    def listVoucherGroups(self, args={}, params={}):
        """"""
        url = "captiveportal/voucher/listVoucherGroups/"
        data = {}

        if "provider" not in args.keys():
            return self.log_error("mandatory argument provider is missing")
        else:
            url += args.pop("provider")+"/"

        data = self._get( url, args)
        return data

    def listVouchers(self, args={}, params={}):
        """"""
        url = "captiveportal/voucher/listVouchers/"
        data = {}

        if "group" not in args.keys():
            return self.log_error("mandatory argument group is missing")
        else:
            url += args.pop("group")+"/"

        if "provider" not in args.keys():
            return self.log_error("mandatory argument provider is missing")
        else:
            url += args.pop("provider")+"/"

        data = self._get( url, args)
        return data



# Copyright 2018 Matthew Treinish
#
# This file is part of pyopnsense
#
# pyopnsense is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense. If not, see <http://www.gnu.org/licenses/>.


class APIException(Exception):
    """Representation of the API exception."""

    def __init__(self, status_code=None, resp_body=None, *args, **kwargs):
        """Initialize the API exception."""
        self.resp_body = resp_body
        self.status_code = status_code
        message = kwargs.get('message', resp_body)
        super(APIException, self).__init__(message, *args, **kwargs)



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class zabbixagent_service(client.BaseClient):
    """A client for interacting with the OPNSense's zabbixagentservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net-mgmt/zabbix-agent/src/opnsense/mvc/app/models/OPNsense/ZabbixAgent/ZabbixAgent.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def reconfigure(self, args={}, params={}):
        """"""
        url = "zabbixagent/service/reconfigure/"
        data = {}

        data = self._get( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "zabbixagent/service/restart/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "zabbixagent/service/start/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "zabbixagent/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "zabbixagent/service/stop/"
        data = {}

        data = self._get( url, args)
        return data

class zabbixagent_settings(client.BaseClient):
    """A client for interacting with the OPNSense's zabbixagentsettings API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net-mgmt/zabbix-agent/src/opnsense/mvc/app/models/OPNsense/ZabbixAgent/ZabbixAgent.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addAlias(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/addAlias/"
        data = {}

        data = self._post( url, args)
        return data

    def addUserparameter(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/addUserparameter/"
        data = {}

        data = self._post( url, args)
        return data

    def delAlias(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/delAlias/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delUserparameter(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/delUserparameter/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getAlias(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/getAlias/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getUserparameter(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/getUserparameter/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchAliases(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/searchAliases/"
        data = {}

        data = self._get( url, args)
        return data

    def searchUserparameters(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/searchUserparameters/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setAlias(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/setAlias/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setUserparameter(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/setUserparameter/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleAlias(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/toggleAlias/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleUserparameter(self, args={}, params={}):
        """"""
        url = "zabbixagent/settings/toggleUserparameter/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class tayga_general(client.BaseClient):
    """A client for interacting with the OPNSense's taygageneral API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/tayga/src/opnsense/mvc/app/models/OPNsense/Tayga/General.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "tayga/general/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "tayga/general/set/"
        data = {}

        data = self._get( url, args)
        return data

class tayga_service(client.BaseClient):
    """A client for interacting with the OPNSense's taygaservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/tayga/src/opnsense/mvc/app/models/OPNsense/Tayga/General.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def reconfigure(self, args={}, params={}):
        """"""
        url = "tayga/service/reconfigure/"
        data = {}

        data = self._get( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "tayga/service/restart/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "tayga/service/start/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "tayga/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "tayga/service/stop/"
        data = {}

        data = self._get( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class Core_Firmware(client.BaseClient):
    """A client for interacting with the OPNSense's CoreFirmware API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def audit(self, args={}, params={}):
        """"""
        url = "core/firmware/audit/"
        data = {}

        data = self._post( url, args)
        return data

    def changelog(self, args={}, params={}):
        """"""
        url = "core/firmware/changelog/"
        data = {}

        if "version" not in args.keys():
            return self.log_error("mandatory argument version is missing")
        else:
            url += args.pop("version")+"/"

        data = self._post( url, args)
        return data

    def details(self, args={}, params={}):
        """"""
        url = "core/firmware/details/"
        data = {}

        if "pkg_name" not in args.keys():
            return self.log_error("mandatory argument pkg_name is missing")
        else:
            url += args.pop("pkg_name")+"/"

        data = self._post( url, args)
        return data

    def getFirmwareConfig(self, args={}, params={}):
        """"""
        url = "core/firmware/getFirmwareConfig/"
        data = {}

        data = self._get( url, args)
        return data

    def getFirmwareOptions(self, args={}, params={}):
        """"""
        url = "core/firmware/getFirmwareOptions/"
        data = {}

        data = self._get( url, args)
        return data

    def info(self, args={}, params={}):
        """"""
        url = "core/firmware/info/"
        data = {}

        data = self._get( url, args)
        return data

    def install(self, args={}, params={}):
        """"""
        url = "core/firmware/install/"
        data = {}

        if "pkg_name" not in args.keys():
            return self.log_error("mandatory argument pkg_name is missing")
        else:
            url += args.pop("pkg_name")+"/"

        data = self._post( url, args)
        return data

    def license(self, args={}, params={}):
        """"""
        url = "core/firmware/license/"
        data = {}

        if "pkg_name" not in args.keys():
            return self.log_error("mandatory argument pkg_name is missing")
        else:
            url += args.pop("pkg_name")+"/"

        data = self._post( url, args)
        return data

    def lock(self, args={}, params={}):
        """"""
        url = "core/firmware/lock/"
        data = {}

        if "pkg_name" not in args.keys():
            return self.log_error("mandatory argument pkg_name is missing")
        else:
            url += args.pop("pkg_name")+"/"

        data = self._post( url, args)
        return data

    def poweroff(self, args={}, params={}):
        """"""
        url = "core/firmware/poweroff/"
        data = {}

        data = self._post( url, args)
        return data

    def reboot(self, args={}, params={}):
        """"""
        url = "core/firmware/reboot/"
        data = {}

        data = self._post( url, args)
        return data

    def reinstall(self, args={}, params={}):
        """"""
        url = "core/firmware/reinstall/"
        data = {}

        if "pkg_name" not in args.keys():
            return self.log_error("mandatory argument pkg_name is missing")
        else:
            url += args.pop("pkg_name")+"/"

        data = self._post( url, args)
        return data

    def remove(self, args={}, params={}):
        """"""
        url = "core/firmware/remove/"
        data = {}

        if "pkg_name" not in args.keys():
            return self.log_error("mandatory argument pkg_name is missing")
        else:
            url += args.pop("pkg_name")+"/"

        data = self._post( url, args)
        return data

    def running(self, args={}, params={}):
        """"""
        url = "core/firmware/running/"
        data = {}

        data = self._get( url, args)
        return data

    def setFirmwareConfig(self, args={}, params={}):
        """"""
        url = "core/firmware/setFirmwareConfig/"
        data = {}

        data = self._post( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "core/firmware/status/"
        data = {}

        data = self._get( url, args)
        return data

    def unlock(self, args={}, params={}):
        """"""
        url = "core/firmware/unlock/"
        data = {}

        if "pkg_name" not in args.keys():
            return self.log_error("mandatory argument pkg_name is missing")
        else:
            url += args.pop("pkg_name")+"/"

        data = self._post( url, args)
        return data

    def update(self, args={}, params={}):
        """"""
        url = "core/firmware/update/"
        data = {}

        data = self._post( url, args)
        return data

    def upgrade(self, args={}, params={}):
        """"""
        url = "core/firmware/upgrade/"
        data = {}

        data = self._post( url, args)
        return data

    def upgradestatus(self, args={}, params={}):
        """"""
        url = "core/firmware/upgradestatus/"
        data = {}

        data = self._get( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class diagnostics_activity(client.BaseClient):
    """A client for interacting with the OPNSense's diagnosticsactivity API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def getActivity(self, args={}, params={}):
        """"""
        url = "diagnostics/activity/getActivity/"
        data = {}

        data = self._get( url, args)
        return data

class diagnostics_dns(client.BaseClient):
    """A client for interacting with the OPNSense's diagnosticsdns API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def reverse_lookup(self, args={}, params={}):
        """"""
        url = "diagnostics/dns/reverse_lookup/"
        data = {}

        data = self._get( url, args)
        return data

class diagnostics_firewall(client.BaseClient):
    """A client for interacting with the OPNSense's diagnosticsfirewall API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def log(self, args={}, params={}):
        """"""
        url = f"diagnostics/firewall/log/?limit={args.get('limit')}" 
        data = {}

        data = self._get( url, args)
        return data

    def log_filters(self, args={}, params={}):
        """"""
        url = "diagnostics/firewall/log_filters/"
        data = {}

        data = self._get( url, args)
        return data

    def stats(self, args={}, params={}):
        """"""
        url = "diagnostics/firewall/stats/"
        data = {}

        data = self._get( url, args)
        return data

    def pfStatistcs(self, args={}, params={}):
        """"""
        url = "diagnostics/firewall/pfStatistcs/"
        data = {}

        data = self._get( url, args)
        return data

    def killStates(self, args={}, params={}):
        """"""
        url = "diagnostics/firewall/killStates/"
        data = {}

        data = self._post( url, args)
        return data

    def flushStates(self, args={}, params={}):
        """"""
        url = "diagnostics/firewall/flushStates/"
        data = {}

        data = self._post( url, args)
        return data

    def flushSources(self, args={}, params={}):
        """"""
        url = "diagnostics/firewall/flushSources/"
        data = {}

        data = self._post( url, args)
        return data

    def delState(self, args={}, params={}):
        """"""
        url = "diagnostics/firewall/delState/"
        data = {}

        if "stateid" not in args.keys():
            return self.log_error("mandatory argument stateid is missing")
        else:
            url += args.pop("stateid")

        data = self._post( url, args)
        return data

    def queryStates(self, args={}, params={}):
        """"""
        url = "diagnostics/firewall/queryStates/"
        data = {}

        data = self._post( url, args)
        return data

class diagnostics_interface(client.BaseClient):
    """A client for interacting with the OPNSense's diagnosticsinterface API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def delRoute(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/delRoute/"
        data = {}

        data = self._post( url, args)
        return data

    def flushArp(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/flushArp/"
        data = {}

        data = self._post( url, args)
        return data

    def getArp(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/getArp/"
        data = {}

        data = self._get( url, args)
        return data

    def getBpfStatistics(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/getBpfStatistics/"
        data = {}

        data = self._get( url, args)
        return data

    def getInterfaceNames(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/getInterfaceNames/"
        data = {}

        data = self._get( url, args)
        return data

    def getInterfaceStatistics(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/getInterfaceStatistics/"
        data = {}

        data = self._get( url, args)
        return data

    def getMemoryStatistics(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/getMemoryStatistics/"
        data = {}

        data = self._get( url, args)
        return data

    def getNdp(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/getNdp/"
        data = {}

        data = self._get( url, args)
        return data

    def getNetisrStatistics(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/getNetisrStatistics/"
        data = {}

        data = self._get( url, args)
        return data

    def getProtocolStatistics(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/getProtocolStatistics/"
        data = {}

        data = self._get( url, args)
        return data

    def getRoutes(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/getRoutes/"
        data = {}

        data = self._get( url, args)
        return data

    def getSocketStatistics(self, args={}, params={}):
        """"""
        url = "diagnostics/interface/getSocketStatistics/"
        data = {}

        data = self._get( url, args)
        return data

class diagnostics_netflow(client.BaseClient):
    """A client for interacting with the OPNSense's diagnosticsnetflow API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def cacheStats(self, args={}, params={}):
        """"""
        url = "diagnostics/netflow/cacheStats/"
        data = {}

        data = self._get( url, args)
        return data

    def getconfig(self, args={}, params={}):
        """"""
        url = "diagnostics/netflow/getconfig/"
        data = {}

        data = self._get( url, args)
        return data

    def isEnabled(self, args={}, params={}):
        """"""
        url = "diagnostics/netflow/isEnabled/"
        data = {}

        data = self._get( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "diagnostics/netflow/reconfigure/"
        data = {}

        data = self._post( url, args)
        return data

    def setconfig(self, args={}, params={}):
        """"""
        url = "diagnostics/netflow/setconfig/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "diagnostics/netflow/status/"
        data = {}

        data = self._get( url, args)
        return data

class diagnostics_networkinsight(client.BaseClient):
    """A client for interacting with the OPNSense's diagnosticsnetworkinsight API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def getInterfaces(self, args={}, params={}):
        """"""
        url = "diagnostics/networkinsight/getInterfaces/"
        data = {}

        data = self._get( url, args)
        return data

    def getMetadata(self, args={}, params={}):
        """"""
        url = "diagnostics/networkinsight/getMetadata/"
        data = {}

        data = self._get( url, args)
        return data

    def getProtocols(self, args={}, params={}):
        """"""
        url = "diagnostics/networkinsight/getProtocols/"
        data = {}

        data = self._get( url, args)
        return data

    def getServices(self, args={}, params={}):
        """"""
        url = "diagnostics/networkinsight/getServices/"
        data = {}

        data = self._get( url, args)
        return data

class diagnostics_systemhealth(client.BaseClient):
    """A client for interacting with the OPNSense's diagnosticssystemhealth API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def getInterfaces(self, args={}, params={}):
        """"""
        url = "diagnostics/systemhealth/getInterfaces/"
        data = {}

        data = self._get( url, args)
        return data

    def getRRDlist(self, args={}, params={}):
        """"""
        url = "diagnostics/systemhealth/getRRDlist/"
        data = {}

        data = self._get( url, args)
        return data

class diagnostics_traffic(client.BaseClient):
    """A client for interacting with the OPNSense's diagnosticstraffic API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def Interface(self, args={}, params={}):
        """"""
        url = "diagnostics/traffic/Interface/"
        data = {}

        data = self._get( url, args)
        return data

    def Top(self, args={}, params={}):
        """"""
        url = "diagnostics/traffic/Top/"
        data = {}

        if "interfaces" not in args.keys():
            return self.log_error("mandatory argument interfaces is missing")
        else:
            url += args.pop("interfaces")+"/"

        data = self._get( url, args)
        return data



#!/usr/bin/env python
# Copyright 2018 Matthew Treinish
#

# This file is part of pyopnsense
#
# pyopnsense is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense. If not, see <http://www.gnu.org/licenses/>.
import setuptools

with open("README.rst", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pyopnsense2",
    version="0.0.5",
    author="SecInfra",
    author_email="opensource@secinfra.fr",
    description="pyopnsense2",
    long_description=long_description,
    url="https://github.com/SecInfra/pyopnsense2",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
    install_requires=[
      'requests',
      'pbr',
      'six',
    ],
)



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class firewall_alias(client.BaseClient):
    """A client for interacting with the OPNSense's firewallalias API.
    for more information on used parameters, see : ['https://github.com/opnsense/core/blob/master/src/opnsense/mvc/app/models/OPNsense/Firewall/Alias.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addItem(self, args={}, params={}):
        """"""
        url = "firewall/alias/addItem/"
        data = {}

        data = self._post( url, args)
        return data

    def delItem(self, args={}, params={}):
        """"""
        url = "firewall/alias/delItem/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def export(self, args={}, params={}):
        """"""
        url = "firewall/alias/export/"
        data = {}

        data = self._get( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "firewall/alias/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getAliasUUID(self, args={}, params={}):
        """"""
        url = "firewall/alias/getAliasUUID/"
        data = {}

        if "name" not in args.keys():
            return self.log_error("mandatory argument name is missing")
        else:
            url += args.pop("name")+"/"

        data = self._get( url, args)
        return data

    def getGeoIP(self, args={}, params={}):
        """"""
        url = "firewall/alias/getGeoIP/"
        data = {}

        data = self._get( url, args)
        return data

    def getItem(self, args={}, params={}):
        """"""
        url = "firewall/alias/getItem/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def doImport(self, args={}, params={}):
        """"""
        url = "firewall/alias/import/"
        data = {}

        data = self._post( url, args)
        return data

    def listCountries(self, args={}, params={}):
        """"""
        url = "firewall/alias/listCountries/"
        data = {}

        data = self._get( url, args)
        return data

    def listNetworkAliases(self, args={}, params={}):
        """"""
        url = "firewall/alias/listNetworkAliases/"
        data = {}

        data = self._get( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "firewall/alias/reconfigure/"
        data = {}

        data = self._post( url, args)
        return data

    def searchItem(self, args={}, params={}):
        """"""
        url = "firewall/alias/searchItem/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "firewall/alias/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setItem(self, args={}, params={}):
        """"""
        url = "firewall/alias/setItem/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleItem(self, args={}, params={}):
        """"""
        url = "firewall/alias/toggleItem/"
        data = {}

        if "enabled" not in args.keys():
            return self.log_error("mandatory argument enabled is missing")
        else:
            url += args.pop("enabled")+"/"

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class firewall_alias_util(client.BaseClient):
    """A client for interacting with the OPNSense's firewallalias_util API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def add(self, args={}, params={}):
        """"""
        url = "firewall/alias_util/add/"
        data = {}

        if "aliasName" not in args.keys():
            return self.log_error("mandatory argument aliasName is missing")
        else:
            url += args.pop("aliasName")+"/"

        data = self._post( url, args)
        return data

    def aliases(self, args={}, params={}):
        """"""
        url = "firewall/alias_util/aliases/"
        data = {}

        data = self._get( url, args)
        return data

    def delete(self, args={}, params={}):
        """"""
        url = "firewall/alias_util/delete/"
        data = {}

        if "aliasName" not in args.keys():
            return self.log_error("mandatory argument aliasName is missing")
        else:
            url += args.pop("aliasName")+"/"

        data = self._post( url, args)
        return data

    def find_references(self, args={}, params={}):
        """"""
        url = "firewall/alias_util/find_references/"
        data = {}

        data = self._post( url, args)
        return data

    def flush(self, args={}, params={}):
        """"""
        url = "firewall/alias_util/flush/"
        data = {}

        if "aliasName" not in args.keys():
            return self.log_error("mandatory argument aliasName is missing")
        else:
            url += args.pop("aliasName")+"/"

        data = self._post( url, args)
        return data

    def list(self, args={}, params={}):
        """"""
        url = "firewall/alias_util/list/"
        data = {}

        if "aliasName" not in args.keys():
            return self.log_error("mandatory argument aliasName is missing")
        else:
            url += args.pop("aliasName")+"/"

        data = self._get( url, args)
        return data

    def update_bogons(self, args={}, params={}):
        """"""
        url = "firewall/alias_util/update_bogons/"
        data = {}

        data = self._get( url, args)
        return data

class firewall_category(client.BaseClient):
    """A client for interacting with the OPNSense's firewallcategory API.
    for more information on used parameters, see : ['https://github.com/opnsense/core/blob/master/src/opnsense/mvc/app/models/OPNsense/Firewall/Category.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addItem(self, args={}, params={}):
        """"""
        url = "firewall/category/addItem/"
        data = {}

        data = self._post( url, args)
        return data

    def delItem(self, args={}, params={}):
        """"""
        url = "firewall/category/delItem/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "firewall/category/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getItem(self, args={}, params={}):
        """"""
        url = "firewall/category/getItem/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchItem(self, args={}, params={}):
        """"""
        url = "firewall/category/searchItem/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "firewall/category/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setItem(self, args={}, params={}):
        """"""
        url = "firewall/category/setItem/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class dnscryptproxy_cloak(client.BaseClient):
    """A client for interacting with the OPNSense's dnscryptproxycloak API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/dnscrypt-proxy/src/opnsense/mvc/app/models/OPNsense/Dnscryptproxy/Cloak.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addCloak(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/cloak/addCloak/"
        data = {}

        data = self._post( url, args)
        return data

    def delCloak(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/cloak/delCloak/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/cloak/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getCloak(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/cloak/getCloak/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchCloak(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/cloak/searchCloak/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/cloak/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setCloak(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/cloak/setCloak/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleCloak(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/cloak/toggleCloak/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class dnscryptproxy_dnsbl(client.BaseClient):
    """A client for interacting with the OPNSense's dnscryptproxydnsbl API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/dnscrypt-proxy/src/opnsense/mvc/app/models/OPNsense/Dnscryptproxy/Dnsbl.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/dnsbl/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/dnsbl/set/"
        data = {}

        data = self._get( url, args)
        return data

class dnscryptproxy_forward(client.BaseClient):
    """A client for interacting with the OPNSense's dnscryptproxyforward API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/dnscrypt-proxy/src/opnsense/mvc/app/models/OPNsense/Dnscryptproxy/Forward.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addForward(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/forward/addForward/"
        data = {}

        data = self._post( url, args)
        return data

    def delForward(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/forward/delForward/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/forward/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getForward(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/forward/getForward/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchForward(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/forward/searchForward/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/forward/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setForward(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/forward/setForward/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleForward(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/forward/toggleForward/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class dnscryptproxy_general(client.BaseClient):
    """A client for interacting with the OPNSense's dnscryptproxygeneral API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/dnscrypt-proxy/src/opnsense/mvc/app/models/OPNsense/Dnscryptproxy/General.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/general/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/general/set/"
        data = {}

        data = self._get( url, args)
        return data

class dnscryptproxy_server(client.BaseClient):
    """A client for interacting with the OPNSense's dnscryptproxyserver API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/dnscrypt-proxy/src/opnsense/mvc/app/models/OPNsense/Dnscryptproxy/Server.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addServer(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/server/addServer/"
        data = {}

        data = self._post( url, args)
        return data

    def delServer(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/server/delServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/server/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getServer(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/server/getServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchServer(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/server/searchServer/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/server/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setServer(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/server/setServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleServer(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/server/toggleServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class dnscryptproxy_service(client.BaseClient):
    """A client for interacting with the OPNSense's dnscryptproxyservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/dnscrypt-proxy/src/opnsense/mvc/app/models/OPNsense/Dnscryptproxy/General.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def dnsbl(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/service/dnsbl/"
        data = {}

        data = self._get( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/service/reconfigure/"
        data = {}

        data = self._get( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/service/restart/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/service/start/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/service/stop/"
        data = {}

        data = self._get( url, args)
        return data

class dnscryptproxy_whitelist(client.BaseClient):
    """A client for interacting with the OPNSense's dnscryptproxywhitelist API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/dns/dnscrypt-proxy/src/opnsense/mvc/app/models/OPNsense/Dnscryptproxy/Whitelist.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addWhitelist(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/whitelist/addWhitelist/"
        data = {}

        data = self._post( url, args)
        return data

    def delWhitelist(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/whitelist/delWhitelist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/whitelist/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getWhitelist(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/whitelist/getWhitelist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchWhitelist(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/whitelist/searchWhitelist/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/whitelist/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setWhitelist(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/whitelist/setWhitelist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleWhitelist(self, args={}, params={}):
        """"""
        url = "dnscryptproxy/whitelist/toggleWhitelist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class postfix_address(client.BaseClient):
    """A client for interacting with the OPNSense's postfixaddress API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/mail/postfix/src/opnsense/mvc/app/models/OPNsense/Postfix/Address.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addAddress(self, args={}, params={}):
        """"""
        url = "postfix/address/addAddress/"
        data = {}

        data = self._post( url, args)
        return data

    def delAddress(self, args={}, params={}):
        """"""
        url = "postfix/address/delAddress/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "postfix/address/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getAddress(self, args={}, params={}):
        """"""
        url = "postfix/address/getAddress/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchAddress(self, args={}, params={}):
        """"""
        url = "postfix/address/searchAddress/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "postfix/address/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setAddress(self, args={}, params={}):
        """"""
        url = "postfix/address/setAddress/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleAddress(self, args={}, params={}):
        """"""
        url = "postfix/address/toggleAddress/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class postfix_antispam(client.BaseClient):
    """A client for interacting with the OPNSense's postfixantispam API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/mail/postfix/src/opnsense/mvc/app/models/OPNsense/Postfix/Antispam.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "postfix/antispam/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "postfix/antispam/set/"
        data = {}

        data = self._get( url, args)
        return data

class postfix_domain(client.BaseClient):
    """A client for interacting with the OPNSense's postfixdomain API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/mail/postfix/src/opnsense/mvc/app/models/OPNsense/Postfix/Domain.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addDomain(self, args={}, params={}):
        """"""
        url = "postfix/domain/addDomain/"
        data = {}

        data = self._post( url, args)
        return data

    def delDomain(self, args={}, params={}):
        """"""
        url = "postfix/domain/delDomain/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "postfix/domain/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getDomain(self, args={}, params={}):
        """"""
        url = "postfix/domain/getDomain/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchDomain(self, args={}, params={}):
        """"""
        url = "postfix/domain/searchDomain/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "postfix/domain/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setDomain(self, args={}, params={}):
        """"""
        url = "postfix/domain/setDomain/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleDomain(self, args={}, params={}):
        """"""
        url = "postfix/domain/toggleDomain/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class postfix_general(client.BaseClient):
    """A client for interacting with the OPNSense's postfixgeneral API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/mail/postfix/src/opnsense/mvc/app/models/OPNsense/Postfix/General.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "postfix/general/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "postfix/general/set/"
        data = {}

        data = self._get( url, args)
        return data

class postfix_headerchecks(client.BaseClient):
    """A client for interacting with the OPNSense's postfixheaderchecks API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/mail/postfix/src/opnsense/mvc/app/models/OPNsense/Postfix/Headerchecks.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addHeadercheck(self, args={}, params={}):
        """"""
        url = "postfix/headerchecks/addHeadercheck/"
        data = {}

        data = self._post( url, args)
        return data

    def delHeadercheck(self, args={}, params={}):
        """"""
        url = "postfix/headerchecks/delHeadercheck/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "postfix/headerchecks/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getHeadercheck(self, args={}, params={}):
        """"""
        url = "postfix/headerchecks/getHeadercheck/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchHeaderchecks(self, args={}, params={}):
        """"""
        url = "postfix/headerchecks/searchHeaderchecks/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "postfix/headerchecks/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setHeadercheck(self, args={}, params={}):
        """"""
        url = "postfix/headerchecks/setHeadercheck/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleHeadercheck(self, args={}, params={}):
        """"""
        url = "postfix/headerchecks/toggleHeadercheck/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class postfix_recipient(client.BaseClient):
    """A client for interacting with the OPNSense's postfixrecipient API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/mail/postfix/src/opnsense/mvc/app/models/OPNsense/Postfix/Recipient.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addRecipient(self, args={}, params={}):
        """"""
        url = "postfix/recipient/addRecipient/"
        data = {}

        data = self._post( url, args)
        return data

    def delRecipient(self, args={}, params={}):
        """"""
        url = "postfix/recipient/delRecipient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "postfix/recipient/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getRecipient(self, args={}, params={}):
        """"""
        url = "postfix/recipient/getRecipient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchRecipient(self, args={}, params={}):
        """"""
        url = "postfix/recipient/searchRecipient/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "postfix/recipient/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setRecipient(self, args={}, params={}):
        """"""
        url = "postfix/recipient/setRecipient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleRecipient(self, args={}, params={}):
        """"""
        url = "postfix/recipient/toggleRecipient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class postfix_recipientbcc(client.BaseClient):
    """A client for interacting with the OPNSense's postfixrecipientbcc API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/mail/postfix/src/opnsense/mvc/app/models/OPNsense/Postfix/Recipientbcc.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addRecipientbcc(self, args={}, params={}):
        """"""
        url = "postfix/recipientbcc/addRecipientbcc/"
        data = {}

        data = self._post( url, args)
        return data

    def delRecipientbcc(self, args={}, params={}):
        """"""
        url = "postfix/recipientbcc/delRecipientbcc/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "postfix/recipientbcc/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getRecipientbcc(self, args={}, params={}):
        """"""
        url = "postfix/recipientbcc/getRecipientbcc/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchRecipientbcc(self, args={}, params={}):
        """"""
        url = "postfix/recipientbcc/searchRecipientbcc/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "postfix/recipientbcc/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setRecipientbcc(self, args={}, params={}):
        """"""
        url = "postfix/recipientbcc/setRecipientbcc/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleRecipientbcc(self, args={}, params={}):
        """"""
        url = "postfix/recipientbcc/toggleRecipientbcc/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class postfix_sender(client.BaseClient):
    """A client for interacting with the OPNSense's postfixsender API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/mail/postfix/src/opnsense/mvc/app/models/OPNsense/Postfix/Sender.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addSender(self, args={}, params={}):
        """"""
        url = "postfix/sender/addSender/"
        data = {}

        data = self._post( url, args)
        return data

    def delSender(self, args={}, params={}):
        """"""
        url = "postfix/sender/delSender/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "postfix/sender/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getSender(self, args={}, params={}):
        """"""
        url = "postfix/sender/getSender/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchSender(self, args={}, params={}):
        """"""
        url = "postfix/sender/searchSender/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "postfix/sender/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setSender(self, args={}, params={}):
        """"""
        url = "postfix/sender/setSender/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleSender(self, args={}, params={}):
        """"""
        url = "postfix/sender/toggleSender/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class postfix_senderbcc(client.BaseClient):
    """A client for interacting with the OPNSense's postfixsenderbcc API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/mail/postfix/src/opnsense/mvc/app/models/OPNsense/Postfix/Senderbcc.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addSenderbcc(self, args={}, params={}):
        """"""
        url = "postfix/senderbcc/addSenderbcc/"
        data = {}

        data = self._post( url, args)
        return data

    def delSenderbcc(self, args={}, params={}):
        """"""
        url = "postfix/senderbcc/delSenderbcc/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "postfix/senderbcc/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getSenderbcc(self, args={}, params={}):
        """"""
        url = "postfix/senderbcc/getSenderbcc/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchSenderbcc(self, args={}, params={}):
        """"""
        url = "postfix/senderbcc/searchSenderbcc/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "postfix/senderbcc/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setSenderbcc(self, args={}, params={}):
        """"""
        url = "postfix/senderbcc/setSenderbcc/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleSenderbcc(self, args={}, params={}):
        """"""
        url = "postfix/senderbcc/toggleSenderbcc/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class postfix_sendercanonical(client.BaseClient):
    """A client for interacting with the OPNSense's postfixsendercanonical API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/mail/postfix/src/opnsense/mvc/app/models/OPNsense/Postfix/Sendercanonical.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addSendercanonical(self, args={}, params={}):
        """"""
        url = "postfix/sendercanonical/addSendercanonical/"
        data = {}

        data = self._post( url, args)
        return data

    def delSendercanonical(self, args={}, params={}):
        """"""
        url = "postfix/sendercanonical/delSendercanonical/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "postfix/sendercanonical/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getSendercanonical(self, args={}, params={}):
        """"""
        url = "postfix/sendercanonical/getSendercanonical/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchSendercanonical(self, args={}, params={}):
        """"""
        url = "postfix/sendercanonical/searchSendercanonical/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "postfix/sendercanonical/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setSendercanonical(self, args={}, params={}):
        """"""
        url = "postfix/sendercanonical/setSendercanonical/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleSendercanonical(self, args={}, params={}):
        """"""
        url = "postfix/sendercanonical/toggleSendercanonical/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class postfix_service(client.BaseClient):
    """A client for interacting with the OPNSense's postfixservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/mail/postfix/src/opnsense/mvc/app/models/OPNsense/Postfix/General.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def checkrspamd(self, args={}, params={}):
        """"""
        url = "postfix/service/checkrspamd/"
        data = {}

        data = self._get( url, args)
        return data

    def reconfigure(self, args={}, params={}):
        """"""
        url = "postfix/service/reconfigure/"
        data = {}

        data = self._get( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "postfix/service/restart/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "postfix/service/start/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "postfix/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "postfix/service/stop/"
        data = {}

        data = self._get( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class nginx_bans(client.BaseClient):
    """A client for interacting with the OPNSense's nginxbans API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/www/nginx/src/opnsense/mvc/app/models/OPNsense/Nginx/Nginx.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def delban(self, args={}, params={}):
        """"""
        url = "nginx/bans/delban/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "nginx/bans/get/"
        data = {}

        data = self._get( url, args)
        return data

    def searchban(self, args={}, params={}):
        """"""
        url = "nginx/bans/searchban/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "nginx/bans/set/"
        data = {}

        data = self._get( url, args)
        return data

class nginx_logs(client.BaseClient):
    """A client for interacting with the OPNSense's nginxlogs API.
    for more information on used parameters, see : 

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def accesses(self, args={}, params={}):
        """"""
        url = "nginx/logs/accesses/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def errors(self, args={}, params={}):
        """"""
        url = "nginx/logs/errors/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def stream_accesses(self, args={}, params={}):
        """"""
        url = "nginx/logs/stream_accesses/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def stream_errors(self, args={}, params={}):
        """"""
        url = "nginx/logs/stream_errors/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def tls_handshakes(self, args={}, params={}):
        """"""
        url = "nginx/logs/tls_handshakes/"
        data = {}

        data = self._get( url, args)
        return data

class nginx_service(client.BaseClient):
    """A client for interacting with the OPNSense's nginxservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/www/nginx/src/opnsense/mvc/app/models/OPNsense/Nginx/Nginx.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def reconfigure(self, args={}, params={}):
        """"""
        url = "nginx/service/reconfigure/"
        data = {}

        data = self._get( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "nginx/service/restart/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "nginx/service/start/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "nginx/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "nginx/service/stop/"
        data = {}

        data = self._get( url, args)
        return data

    def vts(self, args={}, params={}):
        """"""
        url = "nginx/service/vts/"
        data = {}

        data = self._get( url, args)
        return data

class nginx_settings(client.BaseClient):
    """A client for interacting with the OPNSense's nginxsettings API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/www/nginx/src/opnsense/mvc/app/models/OPNsense/Nginx/Nginx.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addcache_path(self, args={}, params={}):
        """"""
        url = "nginx/settings/addcache_path/"
        data = {}

        data = self._post( url, args)
        return data

    def addcredential(self, args={}, params={}):
        """"""
        url = "nginx/settings/addcredential/"
        data = {}

        data = self._post( url, args)
        return data

    def addcustompolicy(self, args={}, params={}):
        """"""
        url = "nginx/settings/addcustompolicy/"
        data = {}

        data = self._post( url, args)
        return data

    def addhttprewrite(self, args={}, params={}):
        """"""
        url = "nginx/settings/addhttprewrite/"
        data = {}

        data = self._post( url, args)
        return data

    def addhttpserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/addhttpserver/"
        data = {}

        data = self._post( url, args)
        return data

    def addipacl(self, args={}, params={}):
        """"""
        url = "nginx/settings/addipacl/"
        data = {}

        data = self._post( url, args)
        return data

    def addlimit_request_connection(self, args={}, params={}):
        """"""
        url = "nginx/settings/addlimit_request_connection/"
        data = {}

        data = self._post( url, args)
        return data

    def addlimit_zone(self, args={}, params={}):
        """"""
        url = "nginx/settings/addlimit_zone/"
        data = {}

        data = self._post( url, args)
        return data

    def addlocation(self, args={}, params={}):
        """"""
        url = "nginx/settings/addlocation/"
        data = {}

        data = self._post( url, args)
        return data

    def addnaxsirule(self, args={}, params={}):
        """"""
        url = "nginx/settings/addnaxsirule/"
        data = {}

        data = self._post( url, args)
        return data

    def addsecurity_header(self, args={}, params={}):
        """"""
        url = "nginx/settings/addsecurity_header/"
        data = {}

        data = self._post( url, args)
        return data

    def addsnifwd(self, args={}, params={}):
        """"""
        url = "nginx/settings/addsnifwd/"
        data = {}

        data = self._post( url, args)
        return data

    def addstreamserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/addstreamserver/"
        data = {}

        data = self._post( url, args)
        return data

    def addsyslog_target(self, args={}, params={}):
        """"""
        url = "nginx/settings/addsyslog_target/"
        data = {}

        data = self._post( url, args)
        return data

    def addtls_fingerprint(self, args={}, params={}):
        """"""
        url = "nginx/settings/addtls_fingerprint/"
        data = {}

        data = self._post( url, args)
        return data

    def addupstream(self, args={}, params={}):
        """"""
        url = "nginx/settings/addupstream/"
        data = {}

        data = self._post( url, args)
        return data

    def addupstreamserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/addupstreamserver/"
        data = {}

        data = self._post( url, args)
        return data

    def adduserlist(self, args={}, params={}):
        """"""
        url = "nginx/settings/adduserlist/"
        data = {}

        data = self._post( url, args)
        return data

    def delcache_path(self, args={}, params={}):
        """"""
        url = "nginx/settings/delcache_path/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delcredential(self, args={}, params={}):
        """"""
        url = "nginx/settings/delcredential/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delcustompolicy(self, args={}, params={}):
        """"""
        url = "nginx/settings/delcustompolicy/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delhttprewrite(self, args={}, params={}):
        """"""
        url = "nginx/settings/delhttprewrite/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delhttpserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/delhttpserver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delipacl(self, args={}, params={}):
        """"""
        url = "nginx/settings/delipacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def dellimit_request_connection(self, args={}, params={}):
        """"""
        url = "nginx/settings/dellimit_request_connection/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def dellimit_zone(self, args={}, params={}):
        """"""
        url = "nginx/settings/dellimit_zone/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def dellocation(self, args={}, params={}):
        """"""
        url = "nginx/settings/dellocation/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delnaxsirule(self, args={}, params={}):
        """"""
        url = "nginx/settings/delnaxsirule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delsecurity_header(self, args={}, params={}):
        """"""
        url = "nginx/settings/delsecurity_header/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delsnifwd(self, args={}, params={}):
        """"""
        url = "nginx/settings/delsnifwd/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delstreamserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/delstreamserver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delsyslog_target(self, args={}, params={}):
        """"""
        url = "nginx/settings/delsyslog_target/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def deltls_fingerprint(self, args={}, params={}):
        """"""
        url = "nginx/settings/deltls_fingerprint/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delupstream(self, args={}, params={}):
        """"""
        url = "nginx/settings/delupstream/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delupstreamserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/delupstreamserver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def deluserlist(self, args={}, params={}):
        """"""
        url = "nginx/settings/deluserlist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def downloadrules(self, args={}, params={}):
        """"""
        url = "nginx/settings/downloadrules/"
        data = {}

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "nginx/settings/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getcache_path(self, args={}, params={}):
        """"""
        url = "nginx/settings/getcache_path/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getcredential(self, args={}, params={}):
        """"""
        url = "nginx/settings/getcredential/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getcustompolicy(self, args={}, params={}):
        """"""
        url = "nginx/settings/getcustompolicy/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def gethttprewrite(self, args={}, params={}):
        """"""
        url = "nginx/settings/gethttprewrite/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def gethttpserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/gethttpserver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getipacl(self, args={}, params={}):
        """"""
        url = "nginx/settings/getipacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getlimit_request_connection(self, args={}, params={}):
        """"""
        url = "nginx/settings/getlimit_request_connection/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getlimit_zone(self, args={}, params={}):
        """"""
        url = "nginx/settings/getlimit_zone/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getlocation(self, args={}, params={}):
        """"""
        url = "nginx/settings/getlocation/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getnaxsirule(self, args={}, params={}):
        """"""
        url = "nginx/settings/getnaxsirule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getsecurity_header(self, args={}, params={}):
        """"""
        url = "nginx/settings/getsecurity_header/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getsnifwd(self, args={}, params={}):
        """"""
        url = "nginx/settings/getsnifwd/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getstreamserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/getstreamserver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getsyslog_target(self, args={}, params={}):
        """"""
        url = "nginx/settings/getsyslog_target/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def gettls_fingerprint(self, args={}, params={}):
        """"""
        url = "nginx/settings/gettls_fingerprint/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getupstream(self, args={}, params={}):
        """"""
        url = "nginx/settings/getupstream/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getupstreamserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/getupstreamserver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def getuserlist(self, args={}, params={}):
        """"""
        url = "nginx/settings/getuserlist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchcache_path(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchcache_path/"
        data = {}

        data = self._get( url, args)
        return data

    def searchcredential(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchcredential/"
        data = {}

        data = self._get( url, args)
        return data

    def searchcustompolicy(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchcustompolicy/"
        data = {}

        data = self._get( url, args)
        return data

    def searchhttprewrite(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchhttprewrite/"
        data = {}

        data = self._get( url, args)
        return data

    def searchhttpserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchhttpserver/"
        data = {}

        data = self._get( url, args)
        return data

    def searchipacl(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchipacl/"
        data = {}

        data = self._get( url, args)
        return data

    def searchlimit_request_connection(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchlimit_request_connection/"
        data = {}

        data = self._get( url, args)
        return data

    def searchlimit_zone(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchlimit_zone/"
        data = {}

        data = self._get( url, args)
        return data

    def searchlocation(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchlocation/"
        data = {}

        data = self._get( url, args)
        return data

    def searchnaxsirule(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchnaxsirule/"
        data = {}

        data = self._get( url, args)
        return data

    def searchsecurity_header(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchsecurity_header/"
        data = {}

        data = self._get( url, args)
        return data

    def searchsnifwd(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchsnifwd/"
        data = {}

        data = self._get( url, args)
        return data

    def searchstreamserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchstreamserver/"
        data = {}

        data = self._get( url, args)
        return data

    def searchsyslog_target(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchsyslog_target/"
        data = {}

        data = self._get( url, args)
        return data

    def searchtls_fingerprint(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchtls_fingerprint/"
        data = {}

        data = self._get( url, args)
        return data

    def searchupstream(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchupstream/"
        data = {}

        data = self._get( url, args)
        return data

    def searchupstreamserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchupstreamserver/"
        data = {}

        data = self._get( url, args)
        return data

    def searchuserlist(self, args={}, params={}):
        """"""
        url = "nginx/settings/searchuserlist/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "nginx/settings/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setcache_path(self, args={}, params={}):
        """"""
        url = "nginx/settings/setcache_path/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setcredential(self, args={}, params={}):
        """"""
        url = "nginx/settings/setcredential/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setcustompolicy(self, args={}, params={}):
        """"""
        url = "nginx/settings/setcustompolicy/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def sethttprewrite(self, args={}, params={}):
        """"""
        url = "nginx/settings/sethttprewrite/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def sethttpserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/sethttpserver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setipacl(self, args={}, params={}):
        """"""
        url = "nginx/settings/setipacl/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setlimit_request_connection(self, args={}, params={}):
        """"""
        url = "nginx/settings/setlimit_request_connection/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setlimit_zone(self, args={}, params={}):
        """"""
        url = "nginx/settings/setlimit_zone/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setlocation(self, args={}, params={}):
        """"""
        url = "nginx/settings/setlocation/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setnaxsirule(self, args={}, params={}):
        """"""
        url = "nginx/settings/setnaxsirule/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setsecurity_header(self, args={}, params={}):
        """"""
        url = "nginx/settings/setsecurity_header/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setsnifwd(self, args={}, params={}):
        """"""
        url = "nginx/settings/setsnifwd/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setstreamserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/setstreamserver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setsyslog_target(self, args={}, params={}):
        """"""
        url = "nginx/settings/setsyslog_target/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def settls_fingerprint(self, args={}, params={}):
        """"""
        url = "nginx/settings/settls_fingerprint/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setupstream(self, args={}, params={}):
        """"""
        url = "nginx/settings/setupstream/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setupstreamserver(self, args={}, params={}):
        """"""
        url = "nginx/settings/setupstreamserver/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def setuserlist(self, args={}, params={}):
        """"""
        url = "nginx/settings/setuserlist/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data



#!/bin/python3
# Copyright 2021 by opensource@secinfra.fr
# Initially from Matthew Treinish's https://github.com/mtreinish/pyopnsense
# Improved a bit.

#
# This file is part of pyopnsense2
#
# pyopnsense2 is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pyopnsense2 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with pyopnsense2. If not, see <http://www.gnu.org/licenses/>.

from pyopnsense2 import client
from six.moves import urllib
import json

class wireguard_client(client.BaseClient):
    """A client for interacting with the OPNSense's wireguardclient API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/wireguard/src/opnsense/mvc/app/models/OPNsense/Wireguard/Client.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addClient(self, args={}, params={}):
        """"""
        url = "wireguard/client/addClient/"
        data = {}

        data = self._post( url, args)
        return data

    def delClient(self, args={}, params={}):
        """"""
        url = "wireguard/client/delClient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "wireguard/client/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getClient(self, args={}, params={}):
        """"""
        url = "wireguard/client/getClient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchClient(self, args={}, params={}):
        """"""
        url = "wireguard/client/searchClient/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "wireguard/client/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setClient(self, args={}, params={}):
        """"""
        url = "wireguard/client/setClient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleClient(self, args={}, params={}):
        """"""
        url = "wireguard/client/toggleClient/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class wireguard_general(client.BaseClient):
    """A client for interacting with the OPNSense's wireguardgeneral API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/wireguard/src/opnsense/mvc/app/models/OPNsense/Wireguard/General.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def get(self, args={}, params={}):
        """"""
        url = "wireguard/general/get/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "wireguard/general/set/"
        data = {}

        data = self._get( url, args)
        return data

class wireguard_server(client.BaseClient):
    """A client for interacting with the OPNSense's wireguardserver API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/wireguard/src/opnsense/mvc/app/models/OPNsense/Wireguard/Server.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def addServer(self, args={}, params={}):
        """"""
        url = "wireguard/server/addServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def delServer(self, args={}, params={}):
        """"""
        url = "wireguard/server/delServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def get(self, args={}, params={}):
        """"""
        url = "wireguard/server/get/"
        data = {}

        data = self._get( url, args)
        return data

    def getServer(self, args={}, params={}):
        """"""
        url = "wireguard/server/getServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._get( url, args)
        return data

    def searchServer(self, args={}, params={}):
        """"""
        url = "wireguard/server/searchServer/"
        data = {}

        data = self._get( url, args)
        return data

    def set(self, args={}, params={}):
        """"""
        url = "wireguard/server/set/"
        data = {}

        data = self._get( url, args)
        return data

    def setServer(self, args={}, params={}):
        """"""
        url = "wireguard/server/setServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

    def toggleServer(self, args={}, params={}):
        """"""
        url = "wireguard/server/toggleServer/"
        data = {}

        if "uuid" not in args.keys():
            return self.log_error("mandatory argument uuid is missing")
        else:
            url += args.pop("uuid")+"/"

        data = self._post( url, args)
        return data

class wireguard_service(client.BaseClient):
    """A client for interacting with the OPNSense's wireguardservice API.
    for more information on used parameters, see : ['https://github.com/opnsense/plugins/blob/master/net/wireguard/src/opnsense/mvc/app/models/OPNsense/Wireguard/General.xml']

    :param str api_key: The API key to use for requests
    :param str api_secret: The API secret to use for requests
    :param str base_url: The base API endpoint for the OPNsense deployment
    """

    def reconfigure(self, args={}, params={}):
        """"""
        url = "wireguard/service/reconfigure/"
        data = {}

        data = self._get( url, args)
        return data

    def restart(self, args={}, params={}):
        """"""
        url = "wireguard/service/restart/"
        data = {}

        data = self._get( url, args)
        return data

    def showconf(self, args={}, params={}):
        """"""
        url = "wireguard/service/showconf/"
        data = {}

        data = self._get( url, args)
        return data

    def showhandshake(self, args={}, params={}):
        """"""
        url = "wireguard/service/showhandshake/"
        data = {}

        data = self._get( url, args)
        return data

    def start(self, args={}, params={}):
        """"""
        url = "wireguard/service/start/"
        data = {}

        data = self._get( url, args)
        return data

    def status(self, args={}, params={}):
        """"""
        url = "wireguard/service/status/"
        data = {}

        data = self._get( url, args)
        return data

    def stop(self, args={}, params={}):
        """"""
        url = "wireguard/service/stop/"
        data = {}

        data = self._get( url, args)
        return data
